/*
# BUILD sources []
# BUILD api_version_check 0
# BUILD libs ['GLUT']
# BUILD include_dirs []
*/
#include "../config.h"

#if GLUT_XLIB_IMPLEMENTATION >= 13
#include "GLUT.000d.inc"
#elif GLUT_XLIB_IMPLEMENTATION >= 11
#include "GLUT.000b.inc"
#elif GLUT_XLIB_IMPLEMENTATION >= 9
#include "GLUT.0009.inc"
#elif GLUT_XLIB_IMPLEMENTATION >= 7
#include "GLUT.0007.inc"
#elif GLUT_XLIB_IMPLEMENTATION >= 5
#include "GLUT.0005.inc"
#elif GLUT_XLIB_IMPLEMENTATION >= 2
#include "GLUT.0002.inc"
#else
#include "GLUT.0001.inc"
#endif
